FoundryHeader

Enum FoundryHeader 

pub enum FoundryHeader {
    Tempo(TempoHeader),
    Ethereum(Header),
}
Consensus header used by Foundry’s multi-network tooling.

The variant order is significant for untagged serde deserialization. Self::Tempo must stay first because Ethereum headers ignore unknown fields and would otherwise silently deserialize Tempo state dumps as Self::Ethereum.

Variants



Tempo(TempoHeader)

Tempo consensus header.



Ethereum(Header)

Ethereum consensus header.

Implementations

Source

impl FoundryHeader

pub const fn new(inner: Header, is_tempo: bool) -> Self

Creates a header for the selected network.

pub const fn tempo(inner: Header) -> Self

Creates a Tempo header from its Ethereum-shaped fields.

pub const fn as_tempo(&self) -> Option<&TempoHeader>

Returns the Tempo header when this is a Tempo block.

pub const fn inner(&self) -> &Header

Returns the inner Ethereum-shaped header.

const fn inner_mut(&mut self) -> &mut Header

pub const fn set_transactions_root(&mut self, transactions_root: B256)

Sets the transactions root shared by Ethereum and Tempo headers.

pub const fn set_ommers_hash(&mut self, ommers_hash: B256)

Sets the ommers root shared by Ethereum and Tempo headers.

pub fn into_inner(self) -> Header

Consumes the wrapper and returns the inner Ethereum-shaped header.

pub fn hash_slow(&self) -> B256

Computes the canonical network header hash.

Methods from Deref<Target = Header>

pub fn hash_slow(&self) -> FixedBytes<32>

Heavy function that will calculate hash of data and will not save the change to metadata.

Use [Header::seal_slow] and unlock if you need the hash to be persistent.

pub fn ommers_hash_is_empty(&self) -> bool

Check if the ommers hash equals to empty hash list.

pub fn transaction_root_is_empty(&self) -> bool

Check if the transaction root equals to empty root.

pub fn blob_fee(&self, blob_params: BlobParams) -> Option<u128>

Returns the blob fee for this block according to the EIP-4844 spec.

Returns None if excess_blob_gas is None

pub fn next_block_blob_fee(&self, blob_params: BlobParams) -> Option<u128>

Returns the blob fee for the next block according to the EIP-4844 spec.

Returns None if excess_blob_gas is None.

See also [Self::next_block_excess_blob_gas]

pub fn next_block_base_fee(&self, base_fee_params: BaseFeeParams) -> Option<u64>

Calculate base fee for next block according to the EIP-1559 spec.

Returns a None if no base fee is set, no EIP-1559 support

pub fn next_block_excess_blob_gas(&self, blob_params: BlobParams) -> Option<u64>

Calculate excess blob gas for the next block according to the EIP-4844 spec.

Returns None if excess_blob_gas, blob_gas_used, or base_fee_per_gas is not set.

pub fn size(&self) -> usize

Calculate a heuristic for the in-memory size of the [Header].

pub fn parent_num_hash(&self) -> NumHash

Returns the parent block’s number and hash

Note: for the genesis block the parent number is 0 and the parent hash is the zero hash.

pub fn num_hash_slow(&self) -> NumHash

Returns the block’s number and hash.

Note: this hashes the header.

pub fn num_hash_with_parent_slow(&self) -> BlockWithParent

Returns the block’s number and hash with the parent hash.

Note: this hashes the header.

pub fn shanghai_active(&self) -> bool

True if the shanghai hardfork is active.

This function checks that the withdrawals root field is present.

pub fn cancun_active(&self) -> bool

True if the Cancun hardfork is active.

This function checks that the blob gas used field is present.

pub fn prague_active(&self) -> bool

True if the Prague hardfork is active.

This function checks that the requests hash is present.

pub fn amsterdam_active(&self) -> bool

True if the Amsterdam hardfork is active.

This function checks that the block access list hash is present.