pub enum FoundryTxEnvelope {
Legacy(Signed<TxLegacy>),
Eip2930(Signed<TxEip2930>),
Eip1559(Signed<TxEip1559>),
Eip4844(Signed<TxEip4844Variant>),
Eip7702(Signed<TxEip7702>),
Deposit(Sealed<TxDeposit>),
PostExec(Sealed<TxPostExec>),
Tempo(AASigned),
}Expand description
Container type for signed, typed transactions.
Variants
Legacy(Signed<TxLegacy>)
Legacy transaction type
Eip2930(Signed<TxEip2930>)
EIP-2930 transaction.
Eip1559(Signed<TxEip1559>)
EIP-1559 transaction.
Eip4844(Signed<TxEip4844Variant>)
EIP-4844 transaction.
Eip7702(Signed<TxEip7702>)
EIP-7702 transaction.
Deposit(Sealed<TxDeposit>)
OP stack deposit transaction.
See https://docs.optimism.io/op-stack/bridging/deposit-flow.
PostExec(Sealed<TxPostExec>)
OP stack post-execution synthetic transaction.
Tempo(AASigned)
Tempo transaction type.
Implementations
Sourceimpl FoundryTxEnvelope
impl FoundryTxEnvelope
Sourcepub fn try_into_eth(self) -> Result<TxEnvelope, Self>
pub fn try_into_eth(self) -> Result<TxEnvelope, Self>
Converts the transaction into an Ethereum [TxEnvelope].
Returns an error if the transaction is not part of the standard Ethereum transaction types.
pub const fn sidecar(&self) -> Option<&TxEip4844WithSidecar>
Sourcepub fn hash(&self) -> B256
pub fn hash(&self) -> B256
Returns the hash of the transaction.
Note
If this transaction has the Impersonated signature then this returns a modified unique hash. This allows us to treat impersonated transactions as unique.
Sourcepub fn has_nonzero_tempo_nonce_key(&self) -> bool
pub fn has_nonzero_tempo_nonce_key(&self) -> bool
Returns true if this is a Tempo transaction with a nonzero nonce key.